@@ -524,7 +524,7 @@ setup_proxy_env (GSettings  *proxy_settings,
 {
   gs_unref_object GSettings *child_settings;
   GString *buf;
-  const char *host;
+  gs_free char *host;
   int port;
   gboolean is_http;
 
@@ -532,7 +532,7 @@ setup_proxy_env (GSettings  *proxy_settings,
 
   child_settings = g_settings_get_child (proxy_settings, child_schema_id);
 
-  g_settings_get (child_settings, "host", "&s", &host);
+  host = g_settings_get_string (child_settings, "host");
   port = g_settings_get_int (child_settings, "port");
   if (host[0] == '\0' || port == 0)
     return;
@@ -544,16 +544,16 @@ setup_proxy_env (GSettings  *proxy_settings,
   if (is_http &&
       g_settings_get_boolean (child_settings, "use-authentication"))
     {
-      const char *user, *password;
-
-      g_settings_get (child_settings, "authentication-user", "&s", &user);
+      gs_free char *user;
 
+      user = g_settings_get_string (child_settings, "authentication-user");
       if (user[0])
         {
+          gs_free char *password;
+
           g_string_append_uri_escaped (buf, user, NULL, TRUE);
 
-          g_settings_get (child_settings, "authentication-password", "&s", &password);
-
+          password = g_settings_get_string (child_settings, "authentication-password");
           if (password[0])
             {
               g_string_append_c (buf, ':');
@@ -572,9 +572,9 @@ setup_autoconfig_proxy_env (GSettings *proxy_settings,
                             GHashTable *env_table)
 {
   /* XXX  Not sure what to do with this.  See bug #596688.
-  const char *url;
+  gs_free char *url;
 
-  g_settings_get (proxy_settings, "autoconfig-url", "&s", &url);
+  url = g_settings_get_string (proxy_settings, "autoconfig-url");
   if (url[0])
     {
       char *proxy;
@@ -589,10 +589,10 @@ setup_ignore_proxy_env (GSettings *proxy_settings,
                         GHashTable *env_table)
 {
   GString *buf;
-  gs_free char **ignore; /* the strings themselves are const */
+  gs_strfreev char **ignore;
   int i;
 
-  g_settings_get (proxy_settings, "ignore-hosts", "^a&s", &ignore);
+  g_settings_get (proxy_settings, "ignore-hosts", "^as", &ignore);
   if (ignore == NULL)
     return;
 
